@@ -139,15 +139,24 @@ maxOptim <- function(fn, grad, hess,
     }
    else {
       ## linear equality and inequality constraints
-                           # equality constraints: A %*% beta + B >= 0
+                           # inequality constraints: A %*% beta + B >= 0
       if(identical(names(constraints), c("ineqA", "ineqB"))) {
+         nra <- nrow(constraints$ineqA)
+         nrb <- nrow(as.matrix(constraints$ineqB))
+         ncb <- ncol(as.matrix(constraints$ineqB))
+         if(ncb != 1) {
+            stop("Inequality constraint B must be a vector ",
+                 "(or Nx1 matrix).  Currently ", ncb, " columns")
+         }
          if(length(dim(constraints$ineqA)) != 2) {
             stop("Inequality constraint A must be a matrix\n",
                  "Current dimension", dim(constraints$ineqA))
          }
-         if(length(constraints$ineqB) != 1) {
-            stop("Inequality constraint B must be a scalar\n",
-                 "Current length", length(constraints$ineqB))
+         if(ncol(constraints$ineqA) != length(start)) {
+            stop("Inequality constraint A must have the same ",
+                 "number of columns as length of the parameter.\n",
+                 "Currently ", ncol(constraints$ineqA),
+                 " and ", length(start), ".")
          }
          if(ncol(constraints$ineqA) != length(start)) {
             stop("Inequality constraint A cannot be matrix multiplied",
@@ -156,11 +165,14 @@ maxOptim <- function(fn, grad, hess,
                  ncol(constraints$ineqA), " matrix,",
                  " start value has lenght ", length(start))
          }
+         if(nra != nrb) {
+            stop("Inequality constraints A and B suggest different number ",
+                 "of constraints: ", nra, " and ", nrb)
+         }
          result <- constrOptim2( theta = start,
                           f = logLikFunc, grad = gradOptim,
                           ineqA=constraints$ineqA,
-                                ineqB=-constraints$ineqB,
-                           # Note the constrOptim uses the B vector with different sign
+                                ineqB=constraints$ineqB,
                                 control=control,
                           method = method, fnOrig = fn, gradOrig = grad,
                           hessOrig = hess, fixed = fixed, start=start, ...)
@@ -177,7 +189,7 @@ maxOptim <- function(fn, grad, hess,
                         maxRoutine = get( maxMethod ),
                         constraints=constraints,
                         print.level=print.level,
-                        iterlim = iterlim,
+ iterlim = iterlim,
                         tol = tol, reltol = reltol, parscale = parscale,
                         alpha = alpha, beta= beta, gamma = gamma,
                         temp = temp, tmax = tmax, random.seed = random.seed,
